@@ -5,10 +5,13 @@ from gcalcli import utils
 from gcalcli.deprecations import parser_allow_deprecated, DeprecatedStoreTrue
 from gcalcli.printer import valid_color_name
 from oauth2client import tools
+from shutil import get_terminal_size
 import copy as _copy
+import datetime
+import locale
 
 DETAILS = ['calendar', 'location', 'length', 'reminders', 'description',
-           'url', 'attendees', 'email', 'attachments']
+           'url', 'attendees', 'email', 'attachments', 'end']
 
 
 PROGRAM_OPTIONS = {
@@ -48,7 +51,7 @@ PROGRAM_OPTIONS = {
                       'help': 'Choose line art style for calendars: ' +
                               '"fancy": for VTcodes, "unicode" for ' +
                               'Unicode box drawing characters, "ascii" ' +
-                              'for old-school plusses, hyphens and pipes.'}
+                              'for old-school plusses, hyphens and pipes.'},
         }
 
 
@@ -89,6 +92,18 @@ def get_details_parser():
     return details_parser
 
 
+def locale_has_24_hours():
+    t = datetime.time(20)
+    formatted = t.strftime(locale.nl_langinfo(locale.T_FMT))
+    return '20' in formatted
+
+
+def get_auto_width():
+    console_width = get_terminal_size().columns
+    day_width = int((console_width - 8) / 7)
+    return day_width if day_width > 9 else 10
+
+
 def get_output_parser(parents=[]):
     output_parser = argparse.ArgumentParser(add_help=False, parents=parents)
     output_parser.add_argument(
@@ -100,12 +115,17 @@ def get_output_parser(parents=[]):
     output_parser.add_argument(
             '--nodeclined', action='store_true', dest='ignore_declined',
             default=False, help='Hide events that have been declined')
+    auto_width = get_auto_width()
     output_parser.add_argument(
-            '--width', '-w', default=10, dest='cal_width', type=validwidth,
-            help='Set output width')
+            '--width', '-w', default=auto_width, dest='cal_width',
+            type=validwidth, help='Set output width')
+    has_24_hours = locale_has_24_hours()
     output_parser.add_argument(
-            '--military', action='store_true', default=False,
+            '--military', action='store_true', default=has_24_hours,
             help='Use 24 hour display')
+    output_parser.add_argument(
+            '--no-military', action='store_false', default=has_24_hours,
+            help='Use 12 hour display', dest='military')
     output_parser.add_argument(
             '--override-color', action='store_true', default=False,
             help='Use overridden color for event')
@@ -167,6 +187,16 @@ def get_cal_query_parser():
     return cal_query_parser
 
 
+def get_updates_parser():
+    updates_parser = argparse.ArgumentParser(add_help=False)
+    updates_parser.add_argument('since', type=utils.get_time_from_str)
+    updates_parser.add_argument(
+            'start',
+            type=utils.get_time_from_str, nargs='?')
+    updates_parser.add_argument('end', type=utils.get_time_from_str, nargs='?')
+    return updates_parser
+
+
 def get_start_end_parser():
     se_parser = argparse.ArgumentParser(add_help=False)
     se_parser.add_argument('start', type=utils.get_time_from_str, nargs='?')
@@ -221,6 +251,7 @@ def get_argument_parser():
 
     remind_parser = get_remind_parser()
     cal_query_parser = get_cal_query_parser()
+    updates_parser = get_updates_parser()
 
     # parsed start and end times
     start_end_parser = get_start_end_parser()
@@ -261,6 +292,14 @@ def get_argument_parser():
             help='get an agenda for a time period',
             description='Get an agenda for a time period.')
 
+    sub.add_parser(
+            'updates',
+            parents=[details_parser, output_parser, updates_parser],
+            help='get updates since a datetime for a time period '
+            '(defaults to through end of current month)',
+            description='Get updates since a datetime for a time period '
+            '(default to through end of current month).')
+
     calw = sub.add_parser(
             'calw', parents=[details_parser, output_parser, cal_query_parser],
             help='get a week-based agenda in calendar format',
