@@ -10,6 +10,7 @@ import random
 import sys
 from unicodedata import east_asian_width
 
+from dateutil.relativedelta import relativedelta
 from datetime import datetime, timedelta, date
 from gcalcli import __program__, __version__
 from gcalcli import utils
@@ -654,18 +655,8 @@ class GoogleCalendarInterface:
         indent = 10 * ' '
         details_indent = 19 * ' '
 
-        if self.options['military']:
-            time_format = '%-5s'
-            tmp_time_str = event['s'].strftime('%H:%M')
-        else:
-            time_format = '%-7s'
-            tmp_time_str = \
-                event['s'].strftime('%I:%M').lstrip('0').rjust(5) + \
-                event['s'].strftime('%p').lower()
-
         if not prefix:
             prefix = indent
-
         self.printer.msg(prefix, self.options['color_date'])
 
         happening_now = event['s'] <= self.now <= event['e']
@@ -680,16 +671,27 @@ class GoogleCalendarInterface:
                 if happening_now and not all_day \
                 else self._calendar_color(event)
 
+        time_width = '%-5s' if self.options['military'] else '%-7s'
         if all_day:
-            fmt = '  ' + time_format + '  %s\n'
+            fmt = '  ' + time_width + '  %s\n'
             self.printer.msg(
                     fmt % ('', self._valid_title(event).strip()),
                     event_color
             )
         else:
-            fmt = '  ' + time_format + '  %s\n'
+            tmp_start_time_str = \
+                utils.agenda_time_fmt(event['s'], self.options['military'])
+            tmp_end_time_str = ''
+            fmt = '  ' + time_width + '   ' + time_width + '  %s\n'
+
+            if self.details.get('end'):
+                tmp_end_time_str = \
+                    utils.agenda_time_fmt(event['e'], self.options['military'])
+                fmt = '  ' + time_width + ' - ' + time_width + '  %s\n'
+
             self.printer.msg(
-                    fmt % (tmp_time_str, self._valid_title(event).strip()),
+                    fmt % (tmp_start_time_str, tmp_end_time_str,
+                           self._valid_title(event).strip()),
                     event_color
             )
 
@@ -1166,6 +1168,25 @@ class GoogleCalendarInterface:
 
         return self._display_queried_events(start, end, search_text, True)
 
+    def UpdatesQuery(self, last_updated_datetime, start=None, end=None):
+        if not start:
+            start = self.now.replace(hour=0, minute=0, second=0, microsecond=0)
+
+        if not end:
+            end = (start + relativedelta(months=+1)).replace(day=1)
+
+        event_list = self._search_for_events(start, end, None)
+        event_list = [e for e in event_list
+                      if (utils.get_time_from_str(e['updated']) >=
+                          last_updated_datetime)]
+        print("Updates since:",
+              last_updated_datetime,
+              "events starting",
+              start,
+              "until",
+              end)
+        return self._iterate_events(start, event_list, year_date=False)
+
     def AgendaQuery(self, start=None, end=None):
         if not start:
             start = self.now.replace(hour=0, minute=0, second=0, microsecond=0)
@@ -1266,9 +1287,23 @@ class GoogleCalendarInterface:
     def AddEvent(self, title, where, start, end, descr, who, reminders, color):
 
         if len(self.cals) != 1:
-            # TODO: get a better name for this exception class
-            # and use it elsewhere
-            raise GcalcliError('You must only specify a single calendar\n')
+            # Calendar not specified. Prompt the user to select it
+            writers = (self.ACCESS_OWNER, self.ACCESS_WRITER)
+            cals_with_write_perms = [cal for cal in self.cals
+                                     if cal['accessRole'] in writers]
+
+            cal_names_with_idx = []
+            for idx, cal in enumerate(cals_with_write_perms):
+                cal_names_with_idx.append(str(idx) + ' ' + cal['summary'])
+            cal_names_with_idx = '\n'.join(cal_names_with_idx)
+            print(cal_names_with_idx)
+            val = get_input(self.printer, 'Specify calendar from above: ',
+                            STR_TO_INT)
+            try:
+                self.cals = [cals_with_write_perms[int(val)]]
+            except IndexError:
+                raise GcalcliError('The entered number doesn\'t appear on the '
+                                   'list above\n')
 
         event = {}
         event['summary'] = title
