@@ -11,6 +11,7 @@ from gcalcli.argparsers import (get_start_end_parser,
                                 get_color_parser,
                                 get_cal_query_parser,
                                 get_output_parser,
+                                get_updates_parser,
                                 get_search_parser)
 from gcalcli.gcal import GoogleCalendarInterface
 from gcalcli.cli import parse_cal_names
@@ -50,6 +51,18 @@ def test_agenda(PatchedGCalI):
     assert PatchedGCalI().AgendaQuery(start=opts.start, end=opts.end) == 0
 
 
+def test_updates(PatchedGCalI):
+    since = datetime(2019, 7, 10)
+    assert PatchedGCalI().UpdatesQuery(since) == 0
+
+    opts = get_updates_parser().parse_args(
+            ['2019-07-10', '2019-07-19', '2019-08-01'])
+    assert PatchedGCalI().UpdatesQuery(
+            last_updated_datetime=opts.since,
+            start=opts.start,
+            end=opts.end) == 0
+
+
 def test_cal_query(capsys, PatchedGCalI):
     opts = vars(get_cal_query_parser().parse_args([]))
     opts.update(vars(get_output_parser().parse_args([])))
